Change Log
----------

0.1.2
~~~~~

2015-02-22

* Supports Python 2.6, 2.7, 3.3, and 3.4.
* Now using Travis CI.

0.1.1
~~~~~

2014-11-27

* Incorporated `DragonMinded <https://github.com/DragonMinded>`_'s `patch to allow credentials store override during app init <https://github.com/SteelPangolin/flask-oidc/pull/1>`_.

0.1.0
~~~~~

2014-07-31

* Initial release.
